@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,16 +16,21 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.service_usage_v1.services.service_usage import pagers
@@ -104,6 +109,42 @@ class ServiceUsageAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return ServiceUsageClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> ServiceUsageTransport:
         """Returns the transport used by the client instance.
@@ -166,17 +207,40 @@ class ServiceUsageAsyncClient:
 
     async def enable_service(
         self,
-        request: serviceusage.EnableServiceRequest = None,
+        request: Union[serviceusage.EnableServiceRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Enable a service so that it can be used with a
         project.
 
+
+        .. code-block:: python
+
+            from google.cloud import service_usage_v1
+
+            def sample_enable_service():
+                # Create a client
+                client = service_usage_v1.ServiceUsageClient()
+
+                # Initialize request argument(s)
+                request = service_usage_v1.EnableServiceRequest(
+                )
+
+                # Make the request
+                operation = client.enable_service(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.service_usage_v1.types.EnableServiceRequest`):
+            request (Union[google.cloud.service_usage_v1.types.EnableServiceRequest, dict]):
                 The request object. Request message for the
                 `EnableService` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -228,9 +292,9 @@ class ServiceUsageAsyncClient:
 
     async def disable_service(
         self,
-        request: serviceusage.DisableServiceRequest = None,
+        request: Union[serviceusage.DisableServiceRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -243,8 +307,31 @@ class ServiceUsageAsyncClient:
         ``FAILED_PRECONDITION`` status if the target service is not
         currently enabled.
 
+
+        .. code-block:: python
+
+            from google.cloud import service_usage_v1
+
+            def sample_disable_service():
+                # Create a client
+                client = service_usage_v1.ServiceUsageClient()
+
+                # Initialize request argument(s)
+                request = service_usage_v1.DisableServiceRequest(
+                )
+
+                # Make the request
+                operation = client.disable_service(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.service_usage_v1.types.DisableServiceRequest`):
+            request (Union[google.cloud.service_usage_v1.types.DisableServiceRequest, dict]):
                 The request object. Request message for the
                 `DisableService` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -296,17 +383,36 @@ class ServiceUsageAsyncClient:
 
     async def get_service(
         self,
-        request: serviceusage.GetServiceRequest = None,
+        request: Union[serviceusage.GetServiceRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Service:
         r"""Returns the service configuration and enabled state
         for a given service.
 
+
+        .. code-block:: python
+
+            from google.cloud import service_usage_v1
+
+            def sample_get_service():
+                # Create a client
+                client = service_usage_v1.ServiceUsageClient()
+
+                # Initialize request argument(s)
+                request = service_usage_v1.GetServiceRequest(
+                )
+
+                # Make the request
+                response = client.get_service(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.service_usage_v1.types.GetServiceRequest`):
+            request (Union[google.cloud.service_usage_v1.types.GetServiceRequest, dict]):
                 The request object. Request message for the `GetService`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -346,9 +452,9 @@ class ServiceUsageAsyncClient:
 
     async def list_services(
         self,
-        request: serviceusage.ListServicesRequest = None,
+        request: Union[serviceusage.ListServicesRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListServicesAsyncPager:
@@ -367,8 +473,28 @@ class ServiceUsageAsyncClient:
         which provides higher throughput and richer filtering
         capability.
 
+
+        .. code-block:: python
+
+            from google.cloud import service_usage_v1
+
+            def sample_list_services():
+                # Create a client
+                client = service_usage_v1.ServiceUsageClient()
+
+                # Initialize request argument(s)
+                request = service_usage_v1.ListServicesRequest(
+                )
+
+                # Make the request
+                page_result = client.list_services(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
-            request (:class:`google.cloud.service_usage_v1.types.ListServicesRequest`):
+            request (Union[google.cloud.service_usage_v1.types.ListServicesRequest, dict]):
                 The request object. Request message for the
                 `ListServices` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -416,9 +542,9 @@ class ServiceUsageAsyncClient:
 
     async def batch_enable_services(
         self,
-        request: serviceusage.BatchEnableServicesRequest = None,
+        request: Union[serviceusage.BatchEnableServicesRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -427,8 +553,31 @@ class ServiceUsageAsyncClient:
         no state changes occur. To enable a single service, use the
         ``EnableService`` method instead.
 
+
+        .. code-block:: python
+
+            from google.cloud import service_usage_v1
+
+            def sample_batch_enable_services():
+                # Create a client
+                client = service_usage_v1.ServiceUsageClient()
+
+                # Initialize request argument(s)
+                request = service_usage_v1.BatchEnableServicesRequest(
+                )
+
+                # Make the request
+                operation = client.batch_enable_services(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.service_usage_v1.types.BatchEnableServicesRequest`):
+            request (Union[google.cloud.service_usage_v1.types.BatchEnableServicesRequest, dict]):
                 The request object. Request message for the
                 `BatchEnableServices` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -480,17 +629,36 @@ class ServiceUsageAsyncClient:
 
     async def batch_get_services(
         self,
-        request: serviceusage.BatchGetServicesRequest = None,
+        request: Union[serviceusage.BatchGetServicesRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> serviceusage.BatchGetServicesResponse:
         r"""Returns the service configurations and enabled states
         for a given list of services.
 
+
+        .. code-block:: python
+
+            from google.cloud import service_usage_v1
+
+            def sample_batch_get_services():
+                # Create a client
+                client = service_usage_v1.ServiceUsageClient()
+
+                # Initialize request argument(s)
+                request = service_usage_v1.BatchGetServicesRequest(
+                )
+
+                # Make the request
+                response = client.batch_get_services(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.service_usage_v1.types.BatchGetServicesRequest`):
+            request (Union[google.cloud.service_usage_v1.types.BatchGetServicesRequest, dict]):
                 The request object. Request message for the
                 `BatchGetServices` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
